<!-- <script src="{{STATIC_URL}}js/plugins/hammer.min.js"></script> -->\
<script src="//cdnjs.cloudflare.com/ajax/libs/hammer.js/1.1.3/hammer.min.js"></script>
<script src="{{STATIC_URL}}js/plugins/jquery.form.js"></script>
<script src="{{STATIC_URL}}js/plugins/load-image.all.min.js"></script>
<script src="{{STATIC_URL}}js/plugins/jquery.cropbox.js"></script>
<script src="{{STATIC_URL}}js/plugins/facebook-canvas.js"></script>
<script src="{{STATIC_URL}}js/paintedword.js"></script>