#fileInput{
  width:0;
  height:0;
  overflow:hidden;
}

#preview { 
  width:390px;
}

#canvas {
  z-index:30;
  pointer-events:none; /* my love! */
}

#preview { 
  position:relative;
  top:91px;
}

#examplePhoto {
	background-color: #E8E8E8;
}

#upload {
	background: url(../img/ajax-loader.gif) no-repeat 50% 36%;	
}